.. _utils:

*********
Utilities
*********
Various utilities get used by `Multidrizzle`, including some to handle WCS
interpretation, trailer file generation, output file generation
and interpretation of the ``MDRIZTAB`` reference file.

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. toctree::
   :maxdepth: 3

   utilfuncs
   wcsutils
   outimage
   mdztab

